@@ -35,7 +35,7 @@ sub main::HELP_MESSAGE()
     {
         print("\tchacha20-ietf chacha20-ietf-poly1305\n");
     }
-    print("\trabbit\n");
+#    print("\trabbit\n");
     print("\trc4-md5\n");
     print("\trc6-128-cfb rc6-128-ctr rc6-128-ofb\n");
     print("\trc6-192-cfb rc6-192-ctr rc6-192-ofb\n");
@@ -128,7 +128,6 @@ Usage: ssserver.pl -s SERVER_ADDR -p SERVER_PORT [-b LOCAL_ADDR]
 	camellia-192-cfb camellia-192-ctr camellia-192-ofb
 	camellia-256-cfb camellia-256-ctr camellia-256-ofb
 	chacha20-ietf chacha20-ietf-poly1305
-	rabbit
 	rc6-128-cfb rc6-128-ctr rc6-128-ofb
 	rc6-192-cfb rc6-192-ctr rc6-192-ofb
 	rc6-256-cfb rc6-256-ctr rc6-256-ofb
@@ -151,7 +150,7 @@ Net::Shadowsocks is a Perl implementation of the shadowsocks (Chinese: 影梭)
 protocol client and server , Shadowsocks is a secure transport protocol based on
 SOCKS Protocol Version 5 (RFC 1928 ).
 
-1. A total of 35 encryption methods are supported:
+1. A total of 34 encryption methods are supported:
 
         aes-128-cfb aes-128-ctr aes-128-gcm aes-128-ofb
 	aes-192-cfb aes-192-ctr aes-192-gcm aes-192-ofb
@@ -160,7 +159,6 @@ SOCKS Protocol Version 5 (RFC 1928 ).
 	camellia-192-cfb camellia-192-ctr camellia-192-ofb
 	camellia-256-cfb camellia-256-ctr camellia-256-ofb
 	chacha20-ietf chacha20-ietf-poly1305
-	rabbit
 	rc6-128-cfb rc6-128-ctr rc6-128-ofb
 	rc6-192-cfb rc6-192-ctr rc6-192-ofb
 	rc6-256-cfb rc6-256-ctr rc6-256-ofb
