@@ -27,10 +27,11 @@ use Crypt::KeyDerivation qw(hkdf);
 use Crypt::Mode::CFB;
 use Crypt::Mode::CTR;
 use Crypt::Mode::OFB;
-use Crypt::OpenSSL::Random qw(random_bytes);
+#use Crypt::OpenSSL::Random qw(random_bytes);
 #use Crypt::NaCl::Sodium;
-use Crypt::Rabbit;
+#use Crypt::Rabbit;
 #use Crypt::Random qw( makerandom_octet );
+use Crypt::PRNG qw(random_bytes);
 use Crypt::RC4::XS;
 use Crypt::Spritz;
 use Digest::MD5;
@@ -75,7 +76,7 @@ our %_ciphers =
         "camellia-256-ofb" => ['Camellia','ofb',32,16],
         "chacha20-ietf" => [undef,undef,32,12],
         "chacha20-ietf-poly1305" =>  [undef,undef,32,12],
-        "rabbit" => ['rabbit','stream',16,16],        
+#        "rabbit" => ['rabbit','stream',16,16],        
         "rc4-md5"  => ['arcfour','stream',16,16],
         "rc6-128-cfb" => ['RC6','cfb',16,16],
         "rc6-128-ctr" => ['RC6','ctr',16,16],
@@ -190,17 +191,17 @@ sub _initialize_cipher($$)
                 $encrypt_rc4_key = $md->digest();
                 $_encryptor = Crypt::RC4::XS->new($encrypt_rc4_key);
         }       
-        elsif($_method eq 'rabbit')
-        {
-            $_key = _EVP_BytesToKey( $_ciphers{$_method}->[2], $_ciphers{$_method}->[3], '', $_password, 1 );
+#        elsif($_method eq 'rabbit')
+#        {
+#            $_key = _EVP_BytesToKey( $_ciphers{$_method}->[2], $_ciphers{$_method}->[3], '', $_password, 1 );
 #            $_iv = makerandom_octet( Length => $_ciphers{$_method}->[3] );
-            $_iv = Crypt::OpenSSL::Random::random_bytes($_ciphers{$_method}->[3]);
-            my $md = Digest::MD5->new();
-            $md->add($_key . $_iv);
-            my $encrypt_rabbit_key = $md->digest();
-            $_encryptor = Crypt::Rabbit->new($encrypt_rabbit_key);
-            #$_decryptor = Crypt::Rabbit->new($encrypted_rabbit_key);
-        }
+#            $_iv = Crypt::OpenSSL::Random::random_bytes($_ciphers{$_method}->[3]);
+#            my $md = Digest::MD5->new();
+#            $md->add($_key . $_iv);
+#            my $encrypt_rabbit_key = $md->digest();
+#            $_encryptor = Crypt::Rabbit->new($encrypt_rabbit_key);
+#            #$_decryptor = Crypt::Rabbit->new($encrypted_rabbit_key);
+#        }
         elsif($_method eq "spritz") 
         {
             $_key = _EVP_BytesToKey(16, 16, '', $_password, 1 );
@@ -359,7 +360,7 @@ Version 0.9.2
 
 Shadowsocks is a secure transport protocol based on SOCKS Protocol Version 5 (RFC 1928 ).Net::Shadowsocks is a Perl implementation of the shadowsocks (Chinese: 影梭) protocol client and server. ssclient.pl is the asynchronous, non-blocking shadowsocks client. ssserver.pl is the asynchronous, non-blocking shadowsocks server. Run ssclient.pl and/or ssserver.pl and follow instructions.
 
-1. A total of 35 encryption methods are supported:
+1. A total of 34 encryption methods are supported:
 
 	aes-128-cfb aes-128-ctr aes-128-gcm aes-128-ofb
 	aes-192-cfb aes-192-ctr aes-192-gcm aes-192-ofb
@@ -368,7 +369,6 @@ Shadowsocks is a secure transport protocol based on SOCKS Protocol Version 5 (RF
 	camellia-192-cfb camellia-192-ctr camellia-192-ofb
 	camellia-256-cfb camellia-256-ctr camellia-256-ofb
 	chacha20-ietf chacha20-ietf-poly1305
-	rabbit
 	rc4-md5
 	rc6-128-cfb rc6-128-ctr rc6-128-ofb
 	rc6-192-cfb rc6-192-ctr rc6-192-ofb
